@@ -3,9 +3,10 @@ package Dist::Zilla::PluginBundle::Author::Plicease;
 use Moose;
 use v5.10;
 use Dist::Zilla;
+use PerlX::Maybe qw( maybe );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.15'; # VERSION
+our $VERSION = '1.27'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -40,7 +41,7 @@ sub configure
     PodWeaver
   ));
   
-  $self->add_plugins([ NextRelease => { format => '%-9v %{yyyy-MM-dd}dT%{HH:mm:ssZ}d' }]);
+  $self->add_plugins([ NextRelease => { format => '%-9v %{yyyy-MM-dd HH:mm:ss Z}d' }]);
     
   $self->add_plugins(qw(
     AutoPrereqs
@@ -50,7 +51,7 @@ sub configure
   ));
 
   $self->add_bundle('Git' => {
-    allow_dirty => [ qw( dist.ini Changes README.pod ) ],
+    allow_dirty => [ qw( dist.ini Changes README.md ) ],
   });
 
   $self->add_plugins([
@@ -72,6 +73,32 @@ sub configure
     ConfirmRelease
 
   ));
+  
+  $self->add_plugins([
+    'ReadmeAnyFromPod' => {
+            type            => 'text',
+            filename        => 'README',
+            location        => 'build', 
+      maybe source_filename => $self->payload->{readme_from},
+    },
+  ]);
+  
+  $self->add_plugins([
+    'ReadmeAnyFromPod' => ReadMePodInRoot => {
+      type                  => 'markdown',
+      filename              => 'README.md',
+      location              => 'root',
+      maybe source_filename => $self->payload->{readme_from},
+    },
+  ]);
+  
+  $self->add_plugins([
+    'Author::Plicease::MarkDownCleanup' => {
+      travis_status => int($self->payload->{travis_status}//0),
+    },
+  ]);
+  
+  $self->add_plugins(qw( Author::Plicease::Recommend ));
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -88,7 +115,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.15
+version 1.27
 
 =head1 SYNOPSIS
 
@@ -112,20 +139,20 @@ This Dist::Zilla plugin bundle is the equivalent to
  [MakeMaker]
  [Manifest]
  [TestRelease]
-
+ 
  [Author::Plicease::PrePodWeaver]
  [PodWeaver]
  [NextRelease]
- format = %-9v %{yyyy-MM-dd}dT%{HH:mm:ssZ}d
+ format = %-9v %{yyyy-MM-dd HH:mm:ss Z}d
  [AutoPrereqs]
  [OurPkgVersion]
  [MetaJSON]
-
+ 
  [@Git]
  allow_dirty = dist.ini
  allow_dirty = Changes
- allow_dirty = README.pod
-
+ allow_dirty = README.md
+ 
  [AutoMetaResources]
  bugtracker.github = user:plicease
  repository.github = user:plicease
@@ -136,6 +163,19 @@ This Dist::Zilla plugin bundle is the equivalent to
  [InstallGuide]
  [MinimumPerl]
  [ConfirmRelease] 
+ 
+ [ReadmeAnyFromPod]
+ type     = text
+ filename = README
+ location = build
+ 
+ [ReadmeAnyFromPod / ReadMePodInRoot]
+ type     = markdown
+ filename = README.md
+ location = root
+ 
+ [Author::Plicease::MarkDownCleanup]
+ [Author::Plicease::Recommend]
 
 =head1 OPTIONS
 
@@ -146,6 +186,19 @@ Specify an alternative to L<[MakeMaker]|Dist::Zilla::Plugin::MakeMaker>
 L<[ModuleBuildTiny]|Dist::Zilla::Plugin::ModuleBuildTiny>, or
 L<[ModuleBuildDatabase]|Dist::Zilla::Plugin::ModuleBuildDatabase> for example).
 
+=head2 readme_from
+
+Which file to pull from for the Readme (must be POD format).  If not 
+specified, then the main module will be used.
+
+=head2 release_tests
+
+If set to true, then include release tests when building.
+
+=head2 travis_status
+
+if set to true, then include a link to the travis build page in the readme.
+
 =head1 SEE ALSO
 
 L<Author::Plicease::Init|Dist::Zilla::Plugin::Author::Plicease::Init>,
